"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const async_middleware_1 = require("async-middleware");
const http_node_1 = require("@essential-projects/http_node");
const consumer_api_contracts_1 = require("@process-engine/consumer_api_contracts");
class ApplicationInfoRouter extends http_node_1.BaseRouter {
    constructor(applicationInfoController) {
        super();
        this.applicationInfoController = applicationInfoController;
    }
    get baseRoute() {
        return 'api/consumer/v1';
    }
    async initializeRouter() {
        this.registerRoutes();
    }
    registerRoutes() {
        const controller = this.applicationInfoController;
        this.router.get(consumer_api_contracts_1.restSettings.paths.getApplicationInfo, errorHandler, async_middleware_1.wrap(controller.getApplicationInfo.bind(controller)));
    }
}
exports.ApplicationInfoRouter = ApplicationInfoRouter;
// TODO:
// There is a bug with either the HTTP extension, express, or the BaseRouter, which causes the "resolveIdentity" middleware to be applied to
// ALL of the consumer api routers, even if they do not make explicit use of that middleware.
// Since this route is designed to be used without the need of any identity, we need to intercept the 401 errors here
// that the middleware throws, if no auth token is provided.
function errorHandler(error, request, response, next) {
    if (error.code === 401) {
        next();
    }
    else {
        next(error);
    }
}
//# sourceMappingURL=application_info_router.js.map